# coding: utf8
# Part of the bioread package for reading BIOPAC data.
#
# Copyright (c) 2016 Board of Regents of the University of Wisconsin System
#
# Written Nate Vack <njvack@wisc.edu> with research from John Ollinger
# at the Waisman Laboratory for Brain Imaging and Behavior, University of
# Wisconsin-Madison
# Project home: http://github.com/njvack/bioread

from __future__ import absolute_import

from bioread import version as ver

version = ver.version_str()
author = "Nate Vack"
author_email = "njvack@freshforever.net"
license = "GPL 2.0"
copyright = "Copyright 2016 Boards of Regent of the University of Wisconsin System"  # noqa
url = "https://github.com/njvack/bioread"
